//
// Copyright (c) 2012, MindFusion LLC - Bulgaria.
//

using System;
using System.Data;
using System.Drawing;
using System.Windows.Forms;

using SolidBrush = MindFusion.Drawing.SolidBrush;


namespace MindFusion.Diagramming.WinForms.Samples.CS.FormEditor
{
	/// <summary>
	/// Summary description for MainForm.
	/// </summary>
	public partial class MainForm : Form
	{
		public MainForm()
		{
			InitializeComponent();
		}

		private void MainForm_Load(object sender, EventArgs e)
		{
			palette.SelectedIndex = 0;

			form.BackBrush = new SolidBrush(BackColor);
			form.ShowGrid = true;
		}

		private void form_NodeCreated(object sender, NodeEventArgs e)
		{
			if (e.Node is ControlNode)
			{
				ControlNode node = (ControlNode)e.Node;
				if (node.Control is Button)
				{
					Button button = (Button)node.Control;
					button.Text = "Button" + form.Nodes.Count.ToString();
				}
			}
		}

		private void btnSave_Click(object sender, EventArgs e)
		{
			SaveFileDialog sfd = new SaveFileDialog();
			sfd.DefaultExt = ".form";
			if (sfd.ShowDialog() == DialogResult.OK)
				form.SaveToFile(sfd.FileName);
		}

		private void btnLoad_Click(object sender, EventArgs e)
		{
			OpenFileDialog ofd = new OpenFileDialog();
			ofd.DefaultExt = ".form";
			if (ofd.ShowDialog() == DialogResult.OK)
				form.LoadFromFile(ofd.FileName);
		}

		private void palette_SelectedIndexChanged(object sender, EventArgs e)
		{
			switch (palette.SelectedIndex)
			{
			case 0:
				formView.DefaultControlType = typeof(Button);
				return;
			case 1:
				formView.DefaultControlType = typeof(TextBox);
				return;
			case 2:
				formView.DefaultControlType = typeof(Label);
				return;
			}
		}

		private void form_InitializeNode(object sender, NodeEventArgs e)
		{
			ControlNode node = e.Node as ControlNode;
			if (node != null)
			{
				TextBox tbox = node.Control as TextBox;
				if (tbox != null)
					tbox.Multiline = true;

				Label label = node.Control as Label;
				if (label != null)
					label.Text = "Label";
			}
		}

		private void form_NodeActivated(object sender, NodeEventArgs e)
		{
			ControlNode node = e.Node as ControlNode;
			if (node != null)
			{
				props.SelectedObject = node.Control;
			}
		}
	}
}